@@ -2,6 +2,8 @@
 
 import subprocess
 import sys
+import shlex
+
 import requests
 
 from .curl_utils import CurlUtils
@@ -23,7 +25,7 @@ def do_curl():
     upload_contents = list(map(lambda content: dict(content=content.content, highlightName=content.lexer.name.lower()),
                                curl_utils.contents))
     result = requests.post(f'{server_url}/instants', json={
-        "commands": ['curl'] + sys.argv[1:],
+        "commands": shlex.join(['curl'] + sys.argv[1:]),
         "contents": upload_contents
     })
     union_id = result.content.decode("utf-8")
